var OutlineViewDataSource_1;
import "@nativescript/macos-node-api";
import { Event } from "../../dom/dom-utils.js";
import { native } from "../decorators/native.js";
import { view } from "../decorators/view.js";
import { View } from "../view/view.js";
export class OutlineClickEvent extends Event {
    constructor(index, eventDict) {
        super("click", eventDict);
        this.index = index;
    }
}
let OutlineViewDataSource = OutlineViewDataSource_1 = class OutlineViewDataSource extends NSObject {
    static initWithOwner(owner) {
        const dataSource = OutlineViewDataSource_1.new();
        dataSource._owner = owner;
        return dataSource;
    }
    get outline() {
        return this._owner?.deref();
    }
    outlineViewNumberOfChildrenOfItem(_outlineView, item) {
        if (item) {
            return item.children.length - 2;
        }
        else {
            return this.outline.children.length;
        }
    }
    outlineViewViewForTableColumnItem(_outlineView, _tableColumn, item) {
        return item.nativeView;
    }
    outlineViewIsItemExpandable(_outlineView, item) {
        return item.children.length > 2;
    }
    outlineViewChildOfItem(_outlineView, index, item) {
        if (item) {
            return item.children[index + 2];
        }
        else {
            return this.outline.children[index];
        }
    }
    outlineViewObjectValueForTableColumnByItem(_outlineView, _tableColumn, item) {
        return item;
    }
    outlineViewSelectionDidChange(notification) {
        const outlineView = notification.object;
        const owner = this.outline;
        if (owner && outlineView) {
            owner.dispatchEvent(new OutlineClickEvent(outlineView.selectedRow));
        }
    }
};
OutlineViewDataSource.ObjCProtocols = [NSOutlineViewDataSource, NSOutlineViewDelegate];
OutlineViewDataSource = OutlineViewDataSource_1 = __decorate([
    NativeClass
], OutlineViewDataSource);
let Outline = class Outline extends View {
    constructor() {
        super(...arguments);
        this.nativeView = undefined;
    }
    initNativeView() {
        const outline = NSOutlineView.new();
        this.dataSource = OutlineViewDataSource.initWithOwner(new WeakRef(this));
        outline.headerView = null;
        outline.indentationPerLevel = 10;
        outline.allowsColumnReordering = false;
        outline.allowsColumnResizing = false;
        outline.allowsColumnSelection = false;
        outline.allowsEmptySelection = false;
        outline.rowSizeStyle = NSTableViewRowSizeStyle.Medium;
        outline.delegate = this.dataSource;
        outline.dataSource = this.dataSource;
        const tableColumn = NSTableColumn.alloc().initWithIdentifier("Column");
        outline.addTableColumn(tableColumn);
        outline.outlineTableColumn = tableColumn;
        this.nativeView = outline;
        return this.nativeView;
    }
    addNativeChild(_child) {
        this.nativeView?.reloadData();
        this.nativeView?.expandItem(_child);
    }
    removeNativeChild(_child) {
        this.nativeView?.reloadData();
    }
};
__decorate([
    native({
        setNative(view, _key, value) {
            if (view.nativeView) {
                view.nativeView.indentationPerLevel = value;
            }
        },
    }),
    __metadata("design:type", Number)
], Outline.prototype, "identationPerLevel", void 0);
__decorate([
    native({
        setNative(view, _key, value) {
            if (view.nativeView) {
                view.nativeView.rowSizeStyle = value;
            }
        },
    }),
    __metadata("design:type", Object)
], Outline.prototype, "rowSizeStyle", void 0);
Outline = __decorate([
    view({
        name: "HTMLOutlineElement",
        tagName: "outline",
    })
], Outline);
export { Outline };
//# sourceMappingURL=outline.js.map