import { native } from "../decorators/native.js";
import { view } from "../decorators/view.js";
import { ViewBase } from "../view/view-base.js";
import { SplitViewController } from "./split-view-controller.js";
let SplitView = class SplitView extends ViewBase {
    constructor() {
        super(...arguments);
        this.nativeView = undefined;
        this.isPresented = false;
        /**
         * SplitView is instead added as a subview to the current viewController's view.
         */
        this.shouldAttachToParentNativeView = false;
        // Disable yoga layout for SplitView. SplitView must resize it's
        // direct childern using AutoLayout.
        this._isEnabled = false;
    }
    initNativeView() {
        this.viewController = SplitViewController.new();
        this.nativeView = this.viewController.splitView;
        this.viewController._owner = new WeakRef(this);
        return this.nativeView;
    }
    addNativeChild(child) {
        if (child.splitViewItem && child.nativeView && child.viewController) {
            this.viewController?.addSplitViewItem(child.splitViewItem);
        }
    }
    removeNativeChild(child) {
        if (child.splitViewItem && child.viewController) {
            this.viewController?.removeSplitViewItem(child.splitViewItem);
        }
    }
    insertBefore(node, child) {
        if (node.nodeName === "SIDE-BAR" ||
            node.nodeName === "CONTENT-LIST" ||
            node.nodeName === "SPLIT-VIEW-ITEM") {
            super.insertBefore(node, child);
            return node;
        }
        else {
            throw new Error(`Cannot add ${node.nodeName} as child to SplitView.SplitView can only have side-bar and content-list as children.`);
        }
    }
    applyLayout() {
        if (this.nativeView &&
            this.viewController?.view &&
            this.parentNode?.nativeView) {
            this.viewController.view.frame = this.parentNode.nativeView.frame;
            if (!this.isPresented) {
                this.isPresented = true;
                this.presentViewController();
            }
        }
    }
    connectedCallback() {
        super.connectedCallback();
    }
    presentViewController() {
        if (this.parentNode?.nodeName === "WINDOW") {
            // Make splitview the contentViewController of the current window.
            this.parentNode.nativeView.contentViewController = this.viewController;
            this.parentNode.viewController = this.viewController;
            return;
        }
        const parentViewController = this.parentNode?.viewController;
        if (this.viewController && parentViewController) {
            parentViewController?.addChildViewController(this.viewController);
            parentViewController?.presentViewControllerAnimator(this.viewController, this.viewController);
        }
    }
};
__decorate([
    native({
        setNative: (view, _key, value) => {
            if (view.nativeView) {
                view.nativeView.isVertical = value;
            }
        },
    }),
    __metadata("design:type", Boolean)
], SplitView.prototype, "vertical", void 0);
SplitView = __decorate([
    view({
        name: "HTMLSplitViewElement",
        tagName: "split-view",
    })
], SplitView);
export default SplitView;
//# sourceMappingURL=split-view.js.map